@@ -1,14 +1,16 @@
 import errno
 import logging
 import os
+from datetime import date, datetime, time
 from enum import Enum
 from pathlib import Path
 from shutil import make_archive
-from typing import Tuple, Type, Union
+from typing import Any, Iterable, Optional, Protocol, Tuple, Type, TypeVar, Union
 from zipfile import BadZipFile, ZipFile
 
 from aleph_message.models import MessageType
 from aleph_message.models.execution.program import Encoding
+from pydantic.json import pydantic_encoder
 
 from aleph.sdk.conf import settings
 from aleph.sdk.types import GenericMessage
@@ -79,6 +81,30 @@ def check_unix_socket_valid(unix_socket_path: str) -> bool:
     return True
 
 
+T = TypeVar("T", str, bytes, covariant=True)
+U = TypeVar("U", str, bytes, contravariant=True)
+
+
+class AsyncReadable(Protocol[T]):
+    async def read(self, n: int = -1) -> T:
+        ...
+
+
+class Writable(Protocol[U]):
+    def write(self, buffer: U) -> int:
+        ...
+
+
+async def copy_async_readable_to_buffer(
+    readable: AsyncReadable[T], buffer: Writable[T], chunk_size: int
+):
+    while True:
+        chunk = await readable.read(chunk_size)
+        if not chunk:
+            break
+        buffer.write(chunk)
+
+
 def enum_as_str(obj: Union[str, Enum]) -> str:
     """Returns the value of an Enum, or the string itself when passing a string.
 
@@ -92,3 +118,35 @@ def enum_as_str(obj: Union[str, Enum]) -> str:
         return obj.value
 
     return obj
+
+
+def serialize_list(values: Optional[Iterable[str]]) -> Optional[str]:
+    if values:
+        return ",".join(values)
+    else:
+        return None
+
+
+def _date_field_to_timestamp(date: Optional[Union[datetime, float]]) -> Optional[str]:
+    if date is None:
+        return None
+    elif isinstance(date, float):
+        return str(date)
+    elif hasattr(date, "timestamp"):
+        return str(date.timestamp())
+    else:
+        raise TypeError(f"Invalid type: `{type(date)}`")
+
+
+def extended_json_encoder(obj: Any) -> Any:
+    """
+    Extended JSON encoder for dumping objects that contain pydantic models and datetime objects.
+    """
+    if isinstance(obj, datetime):
+        return obj.timestamp()
+    elif isinstance(obj, date):
+        return obj.toordinal()
+    elif isinstance(obj, time):
+        return obj.hour * 3600 + obj.minute * 60 + obj.second + obj.microsecond / 1e6
+    else:
+        return pydantic_encoder(obj)
